"""
risk/stats
~~~~~~~~~~
"""

from .stats import calculate_significance_matrices
from .fisher_exact import compute_fisher_exact_test
from .hypergeom import compute_hypergeom_test
from .permutation import compute_permutation_test
